@@ -1,5 +1,4 @@
 use crate::{backend::SchemaBuilder, prepare::*, types::*, SchemaStatementBuilder, TableIndex};
-use std::rc::Rc;
 
 /// Drop an index for an existing table
 ///
@@ -28,7 +27,7 @@ use std::rc::Rc;
 /// ```
 #[derive(Debug, Clone)]
 pub struct IndexDropStatement {
-    pub(crate) table: Option<Rc<dyn Iden>>,
+    pub(crate) table: Option<DynIden>,
     pub(crate) index: TableIndex,
 }
 
@@ -58,7 +57,7 @@ impl IndexDropStatement {
     where
         T: Iden,
     {
-        self.table = Some(Rc::new(table));
+        self.table = Some(SeaRc::new(table));
         self
     }
 }
