@@ -10,11 +10,7 @@ use std::str::from_utf8;
 use chrono::NaiveDateTime;
 
 #[cfg(feature = "with-rust_decimal")]
-use ::rust_decimal::Decimal;
-#[cfg(feature = "with-rust_decimal")]
-pub mod rust_decimal {
-    pub use rust_decimal::prelude::ToPrimitive;
-}
+use rust_decimal::Decimal;
 
 #[cfg(feature = "with-uuid")]
 use uuid::Uuid;
@@ -52,12 +48,16 @@ pub enum Value {
     Decimal(Box<Decimal>),
 }
 
-pub trait ValueType {
+pub trait ValueType: ValueTypeDefault {
     fn unwrap(v: Value) -> Self;
 
     fn type_name() -> &'static str;
 }
 
+pub trait ValueTypeDefault {
+    fn default() -> Self;
+}
+
 #[derive(Clone, Debug, PartialEq)]
 pub struct Values(pub Vec<Value>);
 
@@ -117,6 +117,12 @@ macro_rules! type_to_value {
             }
         }
 
+        impl ValueTypeDefault for $type {
+            fn default() -> Self {
+                Default::default()
+            }
+        }
+
         impl ValueType for Option<$type> {
             fn unwrap(v: Value) -> Self {
                 match v {
@@ -129,6 +135,12 @@ macro_rules! type_to_value {
                 concat!("Option<", stringify!($type), ">")
             }
         }
+
+        impl ValueTypeDefault for Option<$type> {
+            fn default() -> Self {
+                Default::default()
+            }
+        }
     };
 }
 
@@ -174,6 +186,22 @@ macro_rules! type_to_box_value {
                 concat!("Option<", stringify!($type), ">")
             }
         }
+
+        impl ValueTypeDefault for Option<$type> {
+            fn default() -> Self {
+                Default::default()
+            }
+        }
+    };
+}
+
+macro_rules! impl_value_type_default {
+    ( $type: ty ) => {
+        impl ValueTypeDefault for $type {
+            fn default() -> Self {
+                Default::default()
+            }
+        }
     };
 }
 
@@ -203,7 +231,9 @@ impl<'a> From<&'a str> for Value {
 }
 
 type_to_box_value!(Vec<u8>, Bytes);
+impl_value_type_default!(Vec<u8>);
 type_to_box_value!(String, String);
+impl_value_type_default!(String);
 
 #[cfg(feature = "with-json")]
 #[cfg_attr(docsrs, doc(cfg(feature = "with-json")))]
@@ -211,6 +241,7 @@ mod with_json {
     use super::*;
 
     type_to_box_value!(Json, Json);
+    impl_value_type_default!(Json);
 }
 
 #[cfg(feature = "with-chrono")]
@@ -219,6 +250,12 @@ mod with_chrono {
     use super::*;
 
     type_to_box_value!(NaiveDateTime, DateTime);
+
+    impl ValueTypeDefault for NaiveDateTime {
+        fn default() -> Self {
+            NaiveDateTime::from_timestamp(0, 0)
+        }
+    }
 }
 
 #[cfg(feature = "with-rust_decimal")]
@@ -227,6 +264,7 @@ mod with_rust_decimal {
     use super::*;
 
     type_to_box_value!(Decimal, Decimal);
+    impl_value_type_default!(Decimal);
 }
 
 #[cfg(feature = "with-uuid")]
@@ -235,6 +273,7 @@ mod with_uuid {
     use super::*;
 
     type_to_box_value!(Uuid, Uuid);
+    impl_value_type_default!(Uuid);
 }
 
 impl Value {
@@ -291,10 +330,19 @@ impl Value {
             _ => panic!("not Value::Decimal"),
         }
     }
+    #[cfg(feature = "with-rust_decimal")]
+    pub fn decimal_to_f64(&self) -> f64 {
+        use rust_decimal::prelude::ToPrimitive;
+        self.as_ref_decimal().to_f64().unwrap()
+    }
     #[cfg(not(feature = "with-rust_decimal"))]
     pub fn as_ref_decimal(&self) -> &bool {
         panic!("not Value::Decimal")
     }
+    #[cfg(not(feature = "with-rust_decimal"))]
+    pub fn decimal_to_f64(&self) -> f64 {
+        0.0
+    }
 }
 
 impl Value {
@@ -454,9 +502,9 @@ pub fn sea_value_to_json_value(v: &Value) -> Json {
         Value::DateTime(v) => v.format("%Y-%m-%d %H:%M:%S").to_string().into(),
         #[cfg(feature = "with-rust_decimal")]
         Value::Decimal(v) => {
-            use self::rust_decimal::ToPrimitive;
+            use rust_decimal::prelude::ToPrimitive;
             v.as_ref().to_f64().unwrap().into()
-        },
+        }
         #[cfg(feature = "with-uuid")]
         Value::Uuid(v) => Json::String(v.to_string()),
     }
